#!/bin/bash

#----------------------------------------------------------------------------
# <>
# Copyright © 2009, Intel Corporation.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms and conditions of the GNU General Public License,
# version 2, as published by the Free Software Foundation.
#
# This program is distributed in the hope it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc., 
# 51 Franklin St - Fifth Floor, Boston, MA 02110-1301 USA.
#
#
#----------------------------------------------------------------------------

#
# IEGD Driver Install Script
#

###############################################################################
#
# Globals
#
###############################################################################

PRODUCT="IEGD"

# Argument vars
VERBOSE=0
UNINSTALL=0
REINSTALL=0
SILENT=0
MAXARGS=3

# Install OpenGL
OPENGL="N";

# Directory where this ./install.sh lives
INSTALL_DIR=$(pwd)

# Distribution Names
DISTRO_FEDORA7="Fedora 7"
DISTRO_UNKNOWN="Unknown"
DISTRO=$DISTRO_UNKNOWN

# X-Server Names
XVERSION_1_3="Xorg-xserver-1.3"
XVERSION_1_4="Xorg-xserver-1.4"
XVERSION_1_5="Xorg-xserver-1.5.3"
XVERSION_1_6="Xorg-xserver-1.6"
XVERSION=$XSERVER_UNKNOWN

# Command Name Paths
LDCFG_CMD="/sbin/ldconfig"
DEPMOD_CMD="/sbin/depmod"
MODPROBE_CMD="/sbin/modprobe"
LSPCI_CMD="/sbin/lspci"

# Error codes
E_OK=0
E_TOOMANYARGS=1
E_NODIR=2
E_NOROOT=3
E_NOCMD=4

# Intel vendor id
INTEL_VEN="8086"
# Device id for Napa, Gen4, and US15
IEGD_NAP_DEV=( '2582' '2782' '2592' '2792' '2772' '2776' '27A2' '27A6' \
	'27AE' '29C2' '29C3' '29B2' '29B3' 'A002' 'A001' 'A012' 'A011' )
IEGD_GEN4_DEV=( '2982' '2983' '29A2' '29A3' '2992' '2993' '2972' '2973' \
	'2A02' '2A03' '2A12' '2A13' '2A42' '2A43' '2E02' '2E03' )
IEGD_PLB_DEV=( '8108' )

# US15 chipset
CHIPSET_US15="0";

# IKM
IKM_EXISTS=0;
IKM_LOADED=0;
BUILD_IKM="y";

###############################################################################
#
# Functions
#
###############################################################################

#------------------------------------------------------------------------------
# Usage text
# 	Prints usage text info for this script.
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
show_usage() {
	# Print usage text
	echo "Usage: ./install.sh [OPTION]..."
	echo "$PRODUCT installation script."
	echo "  -h    this usage text"
	echo "  -r    reinstall"
	echo "  -u    uninstall"
	echo "  -v    verbose output"

	return $E_OK
}

#------------------------------------------------------------------------------
# Verbose
#	Ouputs string if VERBOSE flag is set.
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
verbose() {
	# Check if VERBOSE is set and if we have an argument to the function.
	if [[ $VERBOSE -eq 1 && $# -eq 1 ]]; then
		# Output the text
		echo "  $1"
	fi

	return $E_OK
}

#------------------------------------------------------------------------------
# Save Remove
#	Removes files only if it exists
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
safe_rm() {
	if [[ $# -eq 1 ]]; then
		if [[ -e $1 ]]; then
			rm -v $1
		else
			verbose "$FUNCNAME file $1 does not exist."
		fi
	fi

	return $E_OK
}

#------------------------------------------------------------------------------
# Pre Install
#	Check to make sure all destination directories exist before starting copy.
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
pre_install() {
	verbose "$FUNCNAME Default Installation entry"

	echo ""
	echo "Installing $PRODUCT on "$DISTRO
	echo ""

	# Check to make sure lspci command exists
	if [ ! -e $LSPCI_CMD ]; then
		echo "The command $LSPCI_CMD not found, exiting."
		exit $E_NOCMD
	fi

	# Check for driver install directory
	loc_driver_install_dir="/usr/lib/xorg/modules/drivers"

	if [ ! -d $loc_driver_install_dir ]; then
		echo "The directory $loc_driver_install_dir must exist to install $PRODUCT."
		return $E_NODIR
	fi
	loc_modules_install_dir="/usr/lib/xorg/modules"
	verbose "$FUNCNAME The directory $loc_driver_install_dir exists."

	# Check for man pages install directory
	man_install_dir="/usr/share/man/man4"

	if [ ! -d $man_install_dir ]; then
		echo "The directory $man_install_dir must exist to install $PRODUCT."
		return $E_NODIR
	fi
	verbose "$FUNCNAME The directory $man_install_dir exists."

    # Check for man iegd_escape.3x.gz pages install directory
	man3x_install_dir="/usr/share/man/man3x"

	if [ ! -d $man3x_install_dir ]; then
		echo "The directory $man3x_install_dir must exist to install $PRODUCT."
		return $E_NODIR
	fi
	verbose "$FUNCNAME The directory $man3x_install_dir exists."

	# Check for usr/lib directory
	lib_install_dir="/usr/lib"

	if [ ! -d $lib_install_dir ]; then
		echo "The directory $lib_install_dir must exist to install $PRODUCT."
		return $E_NODIR
	fi
	verbose "$FUNCNAME The directory $lib_install_dir exists."

	if [[ $XVERSION = $XVERSION_1_5 ||  $XVERSION = $XVERSION_1_6 ]]; then
			# Check for /lib directory
			lib_ogl_dir="/lib"

			if [ ! -d $lib_install_dir ]; then
				echo "The directory $lib_ogl_dir must exist to install $PRODUCT."
				return $E_NODIR
			fi
			verbose "$FUNCNAME The directory $lib_ogl_dir exists."
	fi

	# OpenGL input
	# Do not collect OpenGL input if silent install
	if [[ $SILENT -eq 0 ]]; then
		echo -ne "Would you like to install OpenGL? [y/N] "
		read OPENGL
	fi

	if [[ $OPENGL == "Y" || $OPENGL == "y" ]]; then
		opengl_install_dir="$lib_install_dir/dri"

		# Check if OpenGL DRI directory exits
		if [ ! -d $opengl_install_dir ]; then
			echo "The directory $opengl_install_dir must exist to install $PRODUCT."
			return $E_NODIR
		fi
		verbose "$FUNCNAME The directory $opengl_install_dir exists."

		if [ ${#chipset} -eq 0 ]; then
			echo "Chipset not supported. OpenGL will not be installed."
			OPENGL="N"
		fi
		verbose "$FUNCNAME The libGL binaries are $chipset."
	fi
	
	return $E_OK
}

#------------------------------------------------------------------------------
# Copy files
#	Copy driver files
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
copy_files() { 

	# Start copy output on a new line
	echo ""

	# Copy the Driver
	echo "Copying the driver"
	cd "$INSTALL_DIR/../driver/$XVERSION"
	cp iegd_drv.so $loc_driver_install_dir
	cp libXiegd_escape.so.2.0.0 $lib_install_dir

	# Copy Port Drivers	
	cp analog.so $loc_modules_install_dir
	cp hdmi.so $loc_modules_install_dir
	cp lvds.so $loc_modules_install_dir
	cp sdvo.so $loc_modules_install_dir
	cp softpd.so $loc_modules_install_dir
	cp tv.so $loc_modules_install_dir

	# Copy the Man Pages
	cd "$INSTALL_DIR/../driver/$XVERSION"
	if [[ -e "iegd.4.gz" ]]; then
		echo "Copying man pages"
		cp iegd.4.gz $man_install_dir
	else
		verbose "$FUNCNAME File iegd.4.gz not found.No man pages available to install."
	fi
	if [[ -e "iegd_escape.3x.gz" ]]; then
		cp iegd_escape.3x.gz $man3x_install_dir
	else
		verbose "$FUNCNAME File iegd_escape.3x.gz not found.No man pages available to install."
	fi

	# Copy OpenGL files
	if [[ $OPENGL == "Y" || $OPENGL == "y" ]]; then
		#Creating a opengltest file
		local opengltest_filename=".opengltestfile"
		cd "$INSTALL_DIR"
		echo "" > $opengltest_filename
		echo "Copying OpenGL libraries"
		cd "$INSTALL_DIR/../driver/$XVERSION"
		cp iegd_dri.so $opengl_install_dir

		# Check if previous version of OPENGL libraries exists then create a 
		# back up of that file
		if [[ -f "$lib_install_dir/libGL.so.1.2" ]]; then
			mv $lib_install_dir/libGL.so.1.2 $lib_install_dir/__libGL.so.1.2.backup
		fi
		cp $chipset $lib_install_dir/libGL.so.1.2
	fi

	# Copy Video Decode files
	if [[ $CHIPSET_US15 = "1" ]]; then
		if [[ $DISTRO = $DISTRO_FEDORA7 ]]; then
			echo "WARNING: IEGD does not officially support Video Decode on Fedora Core 7."
		fi
		echo "Copying Video Decode libraries"
		cd "$INSTALL_DIR/../driver/$XVERSION"
		cp iegd_drv_video.so $loc_driver_install_dir
		cp libva.so.0.29.0 $lib_install_dir
	fi

	# Copy iegd_info (only for internal tests)
	lib_internal_dir="$INSTALL_DIR/Internal/"	
	if [[ $SILENT -eq 1 ]]; then
		if [ ! -d $lib_install_dir ]; then
			echo "The directory $lib_internal_dir does not exist."
			echo "iegdinfo will not be installed."
		else
			verbose "$FUNCNAME The directory $lib_internal_dir exists."
			cd "$lib_internal_dir"
			cp libiegdinfo.so $lib_install_dir
		fi
	fi

	return $E_OK
}

#------------------------------------------------------------------------------
# Create links
#	Copy driver files
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
create_links() {

	# For re-install/upgrade unlink the libraries
	cd "$lib_install_dir"
	if [[ $REINSTALL -eq 1 ]]; then
		unlink libXiegd_escape.so
		unlink libXiegd_escape.so.2
		if [[ $CHIPSET_US15 == "1" ]]; then
			unlink libva.so
			unlink libva.so.0
		fi
	fi

	# Create Escape Libraries Links
	echo "Creating Escape library links"
	ln -sfv libXiegd_escape.so.2.0.0 libXiegd_escape.so
	ln -sfv libXiegd_escape.so.2.0.0 libXiegd_escape.so.2

	# Create OpenGL Links
	if [[ $OPENGL == "Y" ]]; then
		echo "Creating OpenGL library links"
		cd "$lib_install_dir"
		ln -sfv libGL.so.1.2 libGL.so
		ln -sfv libGL.so.1.2 libGL.so.1
		if [[ $XVERSION = $XVERSION_1_5 ||  $XVERSION = $XVERSION_1_6 ]]; then
			cd "$lib_ogl_dir"
			ln -sfv libexpat.so.1.5.2 libexpat.so.0
		fi
	fi

	# Create Video Decode Links
	if [[ $CHIPSET_US15 == "1" ]]; then
		echo "Creating Video Decode library links"
		cd "$lib_install_dir"
		ln -sfv libva.so.0.29.0 libva.so
		ln -sfv libva.so.0.29.0 libva.so.0
		set LIBVA_DRIVERS_PATH=$loc_driver_install_dir
	fi

	return $E_OK
}


# Should iegd_gui only be installed on FC7?
#------------------------------------------------------------------------------
# IEGD GUI
#	*add here
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
iegd_gui() {

	# Install IEGDGUI shortcut
	cd "$INSTALL_DIR"
	local iegdgui_install_dir="/usr/share/applications"
	local iegdgui_filename="$iegdgui_install_dir/iegdgui.desktop"
	local iegdgui_icon="/usr/share/icons/gnome/scalable/devices/video-display.svg"

	if [[ -e $iegdgui_install_dir ]]; then

		echo "Creating IEGDGUI GNOME shortcut"
		if [[ ! -x ./iegdgui ]]; then
			chmod +x iegdgui
		fi

		# Copy the IEGDGUI application
		cp iegdgui /usr/bin

		# Create GNOME shortcut
		echo "[Desktop Entry]" > $iegdgui_filename 
		echo "Name=IEGD GUI Utility" >> $iegdgui_filename 
		echo "Comment=IEGD Configuration" >> $iegdgui_filename 
		echo "Exec=/usr/bin/iegdgui" >> $iegdgui_filename 
		echo "Icon=$iegdgui_icon" >> $iegdgui_filename  
		echo "Type=Application" >> $iegdgui_filename 
		echo "Encoding=UTF-8" >> $iegdgui_filename  
		echo "Categories=Application;System;" >> $iegdgui_filename  

	fi

	verbose "$FUNCNAME Default Installation exit"

	return $E_OK
}

#------------------------------------------------------------------------------
# Install IKM
#	1. IKM never installed (exists=0 & loaded=0)
#	  	check the 3 places
#    	build, copy, modeprobe the IKM, then run tests
#  2. IKM previously exists and is not currently loaded (exists=1 & loaded=0)
#		lsmod and see if iegd_mod is currently listed
#	  	ask user to build & copy, modprobe, then run tests
#  3. IKM exists and is loaded (exists=1 & loaded=1)
#		ask user to build & copy, modprobe, user needs to restart and manually 
#		run tests
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
ikm() {
	# Check for Linux version
	local version=`uname -r`
	verbose "$version"

	# Check for IKM install directory
	ikm_dir_1="/lib/modules/$version/misc"
	ikm_dir_2="/lib/modules/$version/kernel/drivers/char/drm"
	ikm_dir_3="/lib/modules/$version/kernel/drivers/char/agp"

	if [ -d $ikm_dir_1 ]; then
		echo "IKM previously exists $ikm_dir_1"
		IKM_EXISTS=1
	fi
	if [ -d $ikm_dir_2 ] && [ -d $ikm_dir_3 ]; then
		echo "IKM previously exists $ikm_dir_2 and $ikm_dir_3"
		IKM_EXISTS=1
	fi
	
	# Check if the IKM is currently loaded
	IKM_LOADED=`lsmod | grep "iegd_mod"`
	
	# Ask user to build, copy, and modprobe
	if [[ IKM_EXISTS -eq 1 && $SILENT -eq 0 ]]; then 
		echo -ne "Would you like to install the latest IKM? [y/N] "
		read BUILD_IKM
	fi
	if [[ $BUILD_IKM == "Y" || $BUILD_IKM == "y" ]]; then
		# Install the IKM
		echo "Installing IKM"
		cd "$INSTALL_DIR/../IKM"
		if [[ ! -x ./install.sh ]]; then
			chmod +x install.sh
		fi
		# Run silent if selected	
		if [[ $SILENT -eq 0 ]]; then	
			./install.sh
		else
			./install.sh silent
		fi
	fi

	return $E_OK
}

#------------------------------------------------------------------------------
# Post install
#	Do system configuration operations here
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
post_install() {

	# Do IKM Post-Installation
	$LDCFG_CMD
	$DEPMOD_CMD -a
	ikm_dir_drm="$INSTALL_DIR/../IKM/drm"
	ikm_dir_agp="$INSTALL_DIR/../IKM/agp" 
	if [[ $BUILD_IKM == "Y" || $BUILD_IKM == "y" ]]; then
		$MODPROBE_CMD iegd_mod
		if [ ${#IKM_LOADED} -gt 0 ]; then
			echo "User needs to restart and run tests manually."
			echo "Test files are located at:"
			echo "$ikm_dir_agp/agp_test.c and "
			echo "$ikm_dir_drm/drm_test.c."
			echo "Compile each test >gcc -o agp_test agp_test.c"
			echo "Then Run >./agp_test"
		else
			# Build IKM tests
			cd "$ikm_dir_drm"
			gcc -o drm_test drm_test.c
			cd "$ikm_dir_agp"
			gcc -o agp_test agp_test.c
			echo "Testing IKM"
			if [ $VERBOSE -eq 0 ]; then
				cd "$ikm_dir_agp"			
				./agp_test
				cd "$ikm_dir_drm"
				./drm_test
			else
				cd "$ikm_dir_agp"
				./agp_test -v
				cd "$ikm_dir_drm"
				./drm_test -v
			fi
		fi
	fi
	return $E_OK
}

#------------------------------------------------------------------------------
# Default Uninstall
#	Driver installation function designated the 'default' uninstallation.
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
default_uninstall() {
	verbose "$FUNCNAME Default Uninstallation entry"

	echo "Uninstalling $PRODUCT on "$DISTRO
	echo ""
	
	# Remove Driver
	rm /usr/lib/xorg/modules/drivers/iegd_drv.so

	# Remove Port Drivers
	safe_rm /usr/lib/xorg/modules/analog.so
	safe_rm /usr/lib/xorg/modules/hdmi.so
	safe_rm /usr/lib/xorg/modules/lvds.so
	safe_rm /usr/lib/xorg/modules/sdvo.so
	safe_rm /usr/lib/xorg/modules/softpd.so
	safe_rm /usr/lib/xorg/modules/tv.so

	# Remove Escape libararies
	safe_rm /usr/lib/libXiegd_escape.so.2.0.0
	safe_rm /usr/lib/libXiegd_escape.so
	safe_rm /usr/lib/libXiegd_escape.so.2

	# Remove OpenGL
	local opengltest_filename=".opengltestfile"
	if [ -e "$INSTALL_DIR/$opengltest_filename" ]; then
		safe_rm /usr/lib/dri/iegd_dri.so
		safe_rm /usr/lib/libGL.so.1.2
		safe_rm /usr/lib/libGL.so
		safe_rm /usr/lib/libGL.so.1
	fi
	
	# Undo Rename operations(Opengl)
	local lib_install_dir="/usr/lib"
	if [ -e "$lib_install_dir/__libGL.so.1.2.backup" ]; then
		mv $lib_install_dir/__libGL.so.1.2.backup $lib_install_dir/libGL.so.1.2
	fi

	# Remove the Man Pages
	safe_rm	/usr/share/man/man4/iegd.4.gz
	safe_rm /var/cache/man/cat4/iegd.4.bz2
	safe_rm	/usr/share/man/man3x/iegd_escape.3x.gz
	

	# Remove IEGDGUI shortcut
	#cd "$INSTALL_DIR/../Utilities"
	cd "$INSTALL_DIR"
	local iegdgui_install_dir="/usr/share/applications"
	local iegdgui_filename="$iegdgui_install_dir/iegdgui.desktop"

	safe_rm /usr/bin/iegdgui
	safe_rm $iegdgui_filename
	
	# Remove the opengl test file
	if [ -e "$INSTALL_DIR/$opengltest_filename" ]; then
		safe_rm $INSTALL_DIR/$opengltest_filename
	fi

	# Remove the X version test file
	local xversionFileName=.xversionFile
	if [ -e "$INSTALL_DIR/$xversionFileName" ]; then
		safe_rm $INSTALL_DIR/$xversionFileName
	fi

	# Remove Video Decode
	if [[ $CHIPSETUS15 = "1" ]]; then
		safe_rm /usr/lib/libva.so.0.29.0
		safe_rm /usr/lib/xorg/modules/drivers/iegd_drv_video.so
	fi

	verbose "$FUNCNAME Default Uninstallation exit"

	return $E_OK
}
#------------------------------------------------------------------------------
# Check for OS type
#	Inputs: none
#	Ouputs: none
#	Returns: E_OK
#------------------------------------------------------------------------------
get_distro() {
	# Check for Fedora 7
	if echo $(uname -r) | grep -q "fc7"; then
		verbose "Found Fedora Core 7 distribution"
		DISTRO=$DISTRO_FEDORA7
	else
		verbose "Distribution not Fedora Core 7"
		DISTRO=$DISTRO_UNKNOWN
	fi
	
}
#------------------------------------------------------------------------------
# Check for X-Server Version
#------------------------------------------------------------------------------
get_xversion() {
	# Check for the X version
	local xversionFileName=.xversionFile
        X -version &> $INSTALL_DIR/$xversionFileName
	if echo $(sed -n '3q;2p' $xversionFileName) | grep -q "1.3"; then
		verbose "Found Xorg-xserver-1.3 version"
		XVERSION=$XVERSION_1_3
	elif echo $(sed -n '3q;2p' $xversionFileName) | grep -q "1.4"; then
		verbose "Found Xorg-xserver-1.4 version"
		XVERSION=$XVERSION_1_4
	elif echo $(sed -n '3q;2p' $xversionFileName) | grep -q "1.5.3"; then
		verbose "Found Xorg-xserver-1.5.3 version"
		XVERSION=$XVERSION_1_5
	elif echo $(sed -n '3q;2p' $xversionFileName) | grep -q "1.6"; then
		verbose "Found Xorg-xserver-1.6 version"
		XVERSION=$XVERSION_1_6
	else
		verbose "IEGD does support this" $XVERSION
		return $E_OK
	fi
		
}
#------------------------------------------------------------------------------
# Check for Chipset
# Checks for the chipset for OpenGL and video decode installation
#	Inputs: none
#	Ouputs: none
#------------------------------------------------------------------------------
get_chipset() {
	# Get chipset information
		chipset=""
		local platform=""

		# There are three libGL binaries included in the package that
		# support different hardware types
		# Check for Napa
		for (( i=0;i<${#IEGD_NAP_DEV[@]};i++ )); do
			platform=`$LSPCI_CMD -d "$INTEL_VEN":"${IEGD_NAP_DEV[${i}]}"`
			if [ ${#platform} -gt 0 ]; then
				chipset="libGLgn3.so"
			fi
		done
		# Check for Gen4
		if [ ${#chipset} -eq 0 ]; then
			for (( i=0;i<${#IEGD_GEN4_DEV[@]};i++ )); do
				platform=`$LSPCI_CMD -d "$INTEL_VEN":"${IEGD_GEN4_DEV[${i}]}"`
				if [ ${#platform} -gt 0 ]; then
					chipset="libGLgn4.so"
				fi
			done
		fi
		#Check for US15
		if [ ${#chipset} -eq 0 ]; then
			for (( i=0;i<${#IEGD_PLB_DEV[@]};i++ )); do
				platform=`$LSPCI_CMD -d "$INTEL_VEN":"${IEGD_PLB_DEV[${i}]}"`
				if [ ${#platform} -gt 0 ]; then
					chipset="libGL_ga.so.1.2"
					CHIPSET_US15="1"
				fi
			done
		fi		
}

###############################################################################
#
# Installation Starts Here
#
###############################################################################

#------------------------------------------------------------------------------
# Global Pre-Install
#------------------------------------------------------------------------------

cat <<EOF

Welcome to the $PRODUCT Linux Installer!

This installation script will allow you to install or uninstall $PRODUCT 
on your Linux distribution. 

Currently $DISTRO_FEDORA7 is the only supported distribution.

This script will allow you to install or uninstall $PRODUCT, including 
the X server, OpenGL libraries, and IEGD Kernel Module (IKM).

You may need to disable SELinux security to allow the IEGD driver to
load.  Alternatively, you will need to configure SELinux to allow IEGD
to operate.

EOF

# Process command line arguments
while getopts ":uvhrqg" OPTION; do
case $OPTION in
	g ) OPENGL="Y";;	
	h ) show_usage; exit $E_OK;;
	q ) SILENT=1; verbose "Silent installation";;
	r ) REINSTALL=1;;
	u ) UNINSTALL=1;;
	v ) VERBOSE=1; verbose "Turning on VERBOSE";;
esac
done

verbose "Global Pre-Installation/Uninstallation"

# Which distribution are we running?
get_distro

# Which X Server version?
get_xversion

# Which chipset?
get_chipset

# todo: check for iegdgui permission

# Check for root level permissions
if [ ! $(id -u) == 0 ]; then
	echo ""
	echo "You need to be root to execute this script."
	echo ""
	exit $E_NOROOT
fi 

# Check to make sure all these commands exists (used in global post install)
if [ ! -e $LDCFG_CMD ]; then
	echo "The command $LDCFG_CMD not found, exiting."
	exit $E_NOCMD
fi

if [ ! -e $DEPMOD_CMD ]; then
	echo "The command $DEPMOD_CMD not found, exiting."
	exit $E_NOCMD
fi

if [ ! -e $MODPROBE_CMD ]; then
	echo "The command $MODPROBE_CMD not found, exiting."
	exit $E_NOCMD
fi

#------------------------------------------------------------------------------
# Global Install/Uninstallation
#------------------------------------------------------------------------------
verbose "INSTALL_DIR=$INSTALL_DIR"
verbose "DISTRO=$DISTRO"

if [[ $UNINSTALL -eq 1 ]]; then

	echo -ne "Starting uninstall..."	
	# Check if user would like to continue
	# Skip if silent install
	if [[ $SILENT -eq 0 ]]; then
		# If unsupported distro then ask user if they would like to run the standard
		# install
		echo ""
		echo ""		
		if [[ $DISTRO = $DISTRO_UNKNOWN ]]; then
			distro_input="N"
			echo -ne "Currently only Fedora Core 7 is supported with the uninstall. "  
		fi
		echo -ne "Would you like to continue with the uninstallation? [y/N] "
			read distro_input

			if [[ $distro_input != "Y" && $distro_input != "y" ]]; then
				exit $E_OK
			fi		
	fi

	default_uninstall

	# Uninstall the IKM
	echo "Uninstalling IKM"
	cd "$INSTALL_DIR/../IKM"
	if [[ ! -x ./install.sh ]]; then
		chmod +x install.sh
	fi
	./install.sh uninstall

	verbose "Global Post-Uninstallation"

	# Do IKM Post-Installation
	$DEPMOD_CMD -a
	$LDCFG_CMD

	# Done
	cd $INSTALL_DIR

	echo ""
	echo "Completed $PRODUCT Uninstallation"
	echo ""
else
		
	# Agree to terms of license
	verbose "INSTALL_DIR=$INSTALL_DIR"
	cd "$INSTALL_DIR/../License"
	cat License.txt
	
	# Skip license agreement and unsupported distro check if silent install
	if [[ $SILENT -eq 0 ]]; then
		# Check if user would like to continue
		install_input="N"
		echo ""
		echo ""
		echo -ne "Do you agree to the terms of the license agreement? [y/N] "
		read install_input

		if [[ $install_input != "Y" && $install_input != "y" ]]; then
			exit $E_OK
		fi

		# If unsupported distro then ask user if they would like to run the standard
		# install
		if [[ $DISTRO = $DISTRO_UNKNOWN ]]; then
			distro_input="N"
			echo ""
			echo ""
			echo -ne "Currently only Fedora Core 7 is supported with the installer. "  
			echo -ne "Would you like to continue with the installation anyway? [y/N] "
			read distro_input

			if [[ $distro_input != "Y" && $distro_input != "y" ]]; then
				exit $E_OK
			fi
		fi
	fi	

	# This is a standard install
	pre_install
	copy_files
	create_links
	if [[ $DISTRO = $DISTRO_FEDORA7 ]]; then
		iegd_gui
	fi
	ikm
	post_install

	cd $INSTALL_DIR

	echo ""
	echo "Completed $PRODUCT Installation"
	echo ""
fi

exit $E_OK
